pub struct BoundedOutput {
pub status: Option<ExitStatus>,
pub stdout: Vec<u8>,
pub stderr: Vec<u8>,
pub timed_out: bool,
}Expand description
Result of a time-bounded subprocess run.
Fields
status: Option<ExitStatus>Exit status, or None if the process was killed on timeout.
stdout: Vec<u8>stderr: Vec<u8>timed_out: boolTrue if we killed the child because it exceeded timeout.
Implementations